# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_core_drg) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  A dynamic routing gateway (DRG), which is a virtual router that provides a path for private
network traffic between your VCN and your existing network. You use it with other Networking
Service components to create an IPSec VPN or a connection that uses
Oracle Cloud Infrastructure FastConnect. For more information, see
[Overview of the Networking Service](https://docs.cloud.oracle.com/Content/Network/Concepts/overview.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access, see
[Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you
supply string values using the API.

  Here is an example on how to use this:

      oci_core_drg { 'tenant (root)/my_drg':
        ensure        => 'present',
        freeform_tags => {'test' => 'no'},
      }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:drg_name)

  ensurable

  parameter :name
  parameter :drg_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :defined_tags
  property :freeform_tags
  property :lifecycle_state
  property :time_created
  property :default_drg_route_tables
  property :default_export_drg_route_distribution
  property :default_export_drg_route_distribution_id

  validate do
    validate_reference_propery(:compartment_id, self)
    validate_reference_propery(:default_export_drg_route_distribution_id, self)
  end
end
