# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_core_route_table) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  A collection of `RouteRule` objects, which are used to route packets
based on destination IP to a particular network entity. For more information, see
[Overview of the Networking Service](https://docs.cloud.oracle.com/Content/Network/Concepts/overview.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access, see
[Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you
supply string values using the API.

  Here is an example on how to use this:

    oci_core_route_table { 'tenant (root)/my_route_table':
      ensure      => 'present',
      vcn         => 'my_compartment/my_vcn',
      route_rules => [
        {
          'cidr_block' => '0.0.0.0/0',
          'destination' => '0.0.0.0/0',
          'destination_type' => 'CIDR_BLOCK',
          'network_entity_type' => 'internetgateway',
          'network_entity' => 'my_compartment/my_ig'
        }
      ],
    }
    oci_core_cpe { 'tenant (root)/test_cpe':
      ensure     => 'present',
      ip_address => '10.0.0.1',
    }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:route_table_name)

  ensurable

  parameter :name
  parameter :route_table_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :defined_tags
  property :freeform_tags
  property :lifecycle_state
  property :route_rules
  property :time_created
  property :vcn
  property :vcn_id

  validate do
    validate_reference_propery(:compartment_id, self)
    validate_reference_propery(:vcn_id, self)
  end
end
