# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_core_security_list) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  A set of virtual firewall rules for your VCN. Security lists are configured at the subnet
level, but the rules are applied to the ingress and egress traffic for the individual instances
in the subnet. The rules can be stateful or stateless. For more information, see
[Security Lists](https://docs.cloud.oracle.com/Content/Network/Concepts/securitylists.htm).
**Note:** Compare security lists to {NetworkSecurityGroup}s,
which let you apply a set of security rules to a *specific set of VNICs* instead of an entire
subnet. Oracle recommends using network security groups instead of security lists, although you
can use either or both together.

**Important:** Oracle Cloud Infrastructure Compute service images automatically include firewall rules (for example,
Linux iptables, Windows firewall). If there are issues with some type of access to an instance,
make sure both the security lists associated with the instance's subnet and the instance's
firewall rules are set correctly.

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access, see
[Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you
supply string values using the API.

  Here is an example on how to use this:

    oci_core_security_list { 'tenant (root)/my_security_list':
      ensure                 => 'present',
      vcn                    => 'my_compartment/my_vcn',
      egress_security_rules  => [
      {
        'destination' => '0.0.0.0/0',
        'destination_type' => 'CIDR_BLOCK',
        'is_stateless' => false,
        'protocol' => 'all'
      }],
      ingress_security_rules => [
      {
        'is_stateless' => false,
        'protocol' => '6',
        'source' => '0.0.0.0/0',
        'source_type' => 'CIDR_BLOCK',
        'tcp_options' => {
          'destination_port_range' => {
            'max' => 22,
            'min' => 22
          }
        }
      },
      {
        'icmp_options' => {
          'code' => 4,
          'type' => 3
        },
        'is_stateless' => false,
        'protocol' => '1',
        'source' => '0.0.0.0/0',
        'source_type' => 'CIDR_BLOCK'
      },
      {
        'icmp_options' => {
          'type' => 3
        },
        'is_stateless' => false,
        'protocol' => '1',
        'source' => '10.0.0.0/16',
        'source_type' => 'CIDR_BLOCK'
      }],
    }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:security_list_name)

  ensurable

  parameter :name
  parameter :security_list_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :defined_tags
  property :egress_security_rules
  property :freeform_tags
  property :ingress_security_rules
  property :lifecycle_state
  property :time_created
  property :vcn
  property :vcn_id

  validate do
    validate_reference_propery(:compartment_id, self)
    validate_reference_propery(:vcn_id, self)
  end
end
