# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_core_service_gateway) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  Represents a router that lets your VCN privately access specific Oracle services such as Object
Storage without exposing the VCN to the public internet. Traffic leaving the VCN and destined
for a supported Oracle service (see {#list_services list_services}) is
routed through the service gateway and does not traverse the internet. The instances in the VCN
do not need to have public IP addresses nor be in a public subnet. The VCN does not need an internet gateway
for this traffic. For more information, see
[Access to Oracle Services: Service Gateway](https://docs.cloud.oracle.com/Content/Network/Tasks/servicegateway.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access, see
[Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you
supply string values using the API.

  Here is an example on how to use this:

    oci_core_service_gateway { 'tenant (root)/my_service_gateway':
      ensure     => 'present',
      vcn        => 'my_compartment/my_vcn',
      services   => [],
    }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:service_gateway_name)

  ensurable

  parameter :name
  parameter :service_gateway_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :block_traffic
  property :defined_tags
  property :freeform_tags
  property :lifecycle_state
  property :route_table
  property :route_table_id
  property :services
  property :time_created
  property :vcn
  property :vcn_id

  validate do
    validate_reference_propery(:compartment_id, self)
    validate_reference_propery(:route_table_id, self)
    validate_reference_propery(:vcn_id, self)
  end
end
