# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_core_volume) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  A detachable block volume device that allows you to dynamically expand
the storage capacity of an instance. For more information, see
[Overview of Cloud Volume Storage](https://docs.cloud.oracle.com/Content/Block/Concepts/overview.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access, see
[Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you
supply string values using the API.

  Here is an example on how to use this:

    oci_core_volume { 'tenant (root)/my_volume':
        ensure              => 'present',
        availability_domain => 'arMl:EU-FRANKFURT-1-AD-1',
        size_in_gbs         => 50,
      }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:volume_name)

  ensurable

  parameter :name
  parameter :volume_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :availability_domain
  property :defined_tags
  property :freeform_tags
  property :system_tags
  property :is_hydrated
  property :kms_key
  property :kms_key_id
  property :lifecycle_state
  property :size_in_gbs
  property :size_in_mbs
  property :source_details
  property :time_created
  property :volume_group
  property :volume_group_id
  property :backup_policy
  property :backup_policy_id
  property :vpus_per_gb
  property :is_auto_tune_enabled
  property :auto_tuned_vpus_per_gb
  property :block_volume_replicas

  validate do
    validate_reference_propery(:compartment_id, self)
    validate_reference_propery(:kms_key_id, self)
    validate_reference_propery(:volume_group_id, self)
    validate_reference_propery(:backup_policy_id, self)
  end
end
