# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_core_volume_backup) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  A point-in-time copy of a volume that can then be used to create a new block volume
or recover a block volume. For more information, see
[Overview of Cloud Volume Storage](https://docs.cloud.oracle.com/Content/Block/Concepts/overview.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access, see
[Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you
supply string values using the API.

  Here is an example on how to use this:

    oci_core_volume_backup { 'tenant (root)/my_backup':
        ensure              => 'present',
        volume              => 'my_compartment/my_volume',
      }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:volume_backup_name)

  ensurable

  parameter :name
  parameter :volume_backup_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :defined_tags
  property :system_tags
  property :expiration_time
  property :freeform_tags
  property :kms_key
  property :kms_key_id
  property :lifecycle_state
  property :size_in_gbs
  property :size_in_mbs
  property :source_type
  property :source_volume_backup
  property :source_volume_backup_id
  property :time_created
  property :time_request_received
  property :type
  property :unique_size_in_gbs
  property :unique_size_in_mbs
  property :volume
  property :volume_id

  validate do
    validate_reference_propery(:compartment_id, self)
    validate_reference_propery(:kms_key_id, self)
    validate_reference_propery(:source_volume_backup_id, self)
    validate_reference_propery(:volume_id, self)
  end
end
