# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_identity_group) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  A collection of users who all need the same type of access to a particular set of resources or compartment.
For conceptual information about groups and other IAM Service components, see
[Overview of the IAM Service](https://docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm).

If you're federating with an identity provider (IdP), you need to create mappings between the groups
defined in the IdP and groups you define in the IAM service. For more information, see
[Identity Providers and Federation](https://docs.cloud.oracle.com/Content/Identity/Concepts/federation.htm). Also see
{IdentityProvider} and
{IdpGroupMapping}.

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access,
see [Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you supply string values
using the API.

  Here is an example on how to use this:

    oci_identity_group { 'tenant (root)/my_group':
      ensure => 'present',
      users  => ['my_user_1','my_user_2']
    }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:group_name)

  ensurable

  parameter :name
  parameter :group_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :users
  property :description
  property :time_created
  property :lifecycle_state
  property :inactive_status
  property :freeform_tags
  property :defined_tags

  validate do
    validate_reference_propery(:compartment_id, self)
  end
end
