# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_identity_policy) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  A document that specifies the type of access a group has to the resources in a compartment. For information about
policies and other IAM Service components, see
[Overview of the IAM Service](https://docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm). If you're new to policies, see
[Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

The word \"policy\" is used by people in different ways:

  * An individual statement written in the policy language
  * A collection of statements in a single, named \"policy\" document (which has an Oracle Cloud ID (OCID) assigned to it)
  * The overall body of policies your organization uses to control access to resources

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator.

**Warning:** Oracle recommends that you avoid using any confidential information when you supply string values
using the API.

  Here is an example on how to use this:

    oci_identity_policy { 'tenant (root)/my_policy}':
        ensure        => 'present',
        description   => 'My own policy',
        statements    => ['Allow group Administrators to manage all-resources in compartment my_compartment'],
      }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:policy_name)

  ensurable

  parameter :name
  parameter :policy_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :statements
  property :description
  property :time_created
  property :lifecycle_state
  property :inactive_status
  property :version_date
  property :freeform_tags
  property :defined_tags

  validate do
    validate_reference_propery(:compartment_id, self)
  end
end
