# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# This code is generated by the type generator. Modification will be overwritten
#
require 'puppet_x/enterprisemodules/oci/core'

Puppet::Type.newtype(:oci_identity_user) do
  include Puppet_X::EnterpriseModules::Oci::Type
  desc <<-DESC
  An individual employee or system that needs to manage or use your company's Oracle Cloud Infrastructure
resources. Users might need to launch instances, manage remote disks, work with your cloud network, etc. Users
have one or more IAM Service credentials ({ApiKey},
{UIPassword}, {SwiftPassword} and
{AuthToken}).
For more information, see [User Credentials](https://docs.cloud.oracle.com/Content/API/Concepts/usercredentials.htm)). End users of your
application are not typically IAM Service users. For conceptual information about users and other IAM Service
components, see [Overview of the IAM Service](https://docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm).

These users are created directly within the Oracle Cloud Infrastructure system, via the IAM service.
They are different from *federated users*, who authenticate themselves to the Oracle Cloud Infrastructure
Console via an identity provider. For more information, see
[Identity Providers and Federation](https://docs.cloud.oracle.com/Content/Identity/Concepts/federation.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
talk to an administrator. If you're an administrator who needs to write policies to give users access,
see [Getting Started with Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

**Warning:** Oracle recommends that you avoid using any confidential information when you supply string values
using the API.

  Here is an example on how to use this:

    oci_identity_user { 'tenant (root)/my_user':
      ensure          => 'present',
      description     => 'my user',
    }

  This documentation is generated from the [Ruby OCI SDK](https://github.com/oracle/oci-ruby-sdk).

  DESC

  add_title_attributes(:user_name)
  #
  # The include files contain specific non-generated code for the types
  #
  include_file "puppet/type/#{name}/before_destroy", binding

  ensurable

  parameter :name
  parameter :user_name
  parameter :tenant
  parameter :oci_timeout
  parameter :oci_wait_interval
  parameter :present_states
  parameter :absent_states
  parameter :synchronized
  parameter :compartment
  property  :id
  property  :compartment_id

  property :description
  property :email
  property :identity_provider
  property :identity_provider_id
  property :external_identifier
  property :time_created
  property :lifecycle_state
  property :inactive_status
  property :freeform_tags
  property :defined_tags
  property :capabilities
  property :is_mfa_activated
  property :email_verified
  property :last_successful_login_time
  property :previous_successful_login_time
  property :db_user_name

  validate do
    validate_reference_propery(:compartment_id, self)
    validate_reference_propery(:identity_provider_id, self)
  end
end
